@@ -27,11 +27,11 @@ void on_adjustment_trackvolumes_changed(GtkAdjustment *, gpointer);
 void on_togglebutton_trackvolumes_toggled(GtkToggleButton *, gpointer);
 void on_button_block_clicked(GtkButton *, gpointer);
 gboolean keyboard_event(GtkWidget *, GdkEventKey *, gboolean, struct gui *);
-void on_selection_sysex_changed(GtkTreeSelection *, gpointer);
+void on_selection_message_changed(GtkTreeSelection *, gpointer);
 void on_selection_sectionlist_changed(GtkTreeSelection *, gpointer);
 void on_selection_playseq_changed(GtkTreeSelection *, gpointer);
 void on_selection_blocklist_changed(GtkTreeSelection *, gpointer);
-void on_selection_sysexlist_changed(GtkTreeSelection *, gpointer);
+void on_selection_messagelist_changed(GtkTreeSelection *, gpointer);
 void on_menuitem_edit_cut_activate(GtkMenuItem *, gpointer);
 void on_menuitem_edit_copy_activate(GtkMenuItem *, gpointer);
 void on_menuitem_edit_paste_activate(GtkMenuItem *, gpointer);
