@@ -30,7 +30,7 @@ struct midi {
   int fd;
 };
 
-struct sysex {
+struct message {
   /* Name */
   char *name;
   /* Length in bytes */
@@ -59,21 +59,21 @@ void midi_program_change(struct midi *, unsigned char, unsigned char);
 void midi_channel_pressure(struct midi *, unsigned char, unsigned char);
 /* Sets the pitch wheel value of a MIDI channel */
 void midi_pitch_wheel(struct midi *, unsigned char, unsigned short);
-/* Sends a MIDI SysEx message */
-void midi_system_exclusive(struct midi *, unsigned char *, unsigned short);
+/* Sends a MIDI message */
+void midi_write(struct midi *, unsigned char *, unsigned short);
 /* Send a clock message */
 void midi_clock(struct midi *);
 /* Receives a MIDI message */
 unsigned char *midi_read(struct midi *);
-/* Receives a MIDI SysEx message */
-void midi_read_system_exclusive(struct midi *, struct sysex *, int);
-/* Sets the length of a MIDI SysEx message */
-void sysex_set_length(struct sysex *, unsigned int);
-/* Sets the auto send flag of a MIDI SysEx message */
-void sysex_set_autosend(struct sysex *, unsigned int);
-/* Parses a SysEx element in an XML file */
-struct sysex *sysex_parse(xmlDocPtr, xmlNsPtr, xmlNodePtr);
-/* Saves a SysEx message to an XML file */
-void sysex_save(struct sysex *, int, xmlNodePtr);
+/* Receives a MIDI message */
+void midi_read_system_exclusive(struct midi *, struct message *, int);
+/* Sets the length of a MIDI message */
+void message_set_length(struct message *, unsigned int);
+/* Sets the auto send flag of a MIDI message */
+void message_set_autosend(struct message *, unsigned int);
+/* Parses a element in an XML file */
+struct message *message_parse(xmlDocPtr, xmlNsPtr, xmlNodePtr);
+/* Saves a message to an XML file */
+void message_save(struct message *, int, xmlNodePtr);
 
 #endif
