@@ -22,8 +22,10 @@
 #ifndef _PLAYER_H
 #define _PLAYER_H
 
+#include <glib.h>
 #include "song.h"
 #include "editor.h"
+#include "midi.h"
 
 /* Player mode */
 enum {
@@ -50,6 +52,11 @@ enum {
   VALUES_PITCH_WHEEL=130
 };
 
+enum {
+  SCHED_RTC,
+  SCHED_NANOSLEEP
+};
+
 struct player {
   /* Current location in song */
   unsigned int section, playseq, position, block, line, tick;
@@ -57,18 +64,25 @@ struct player {
   struct song *song;
   /* Player mode */
   unsigned int mode;
+  /* Player scheduling mode */
+  unsigned int sched;
   /* Status of tracks; notes playing */
   char *trackstatus;
   /* MIDI controller values; one for each controller on each channel */
   unsigned char midicontrollervalues[16*VALUES];
   /* For measuring how long the song has been playing */
   struct timeval playingstarted, playedsofar;
-  /* The initialization status of the player thread */
-  int threadstatus;
   /* Player thread pointer */
-  pthread_t thread;
-  /* MIDI device file descriptor */
-  int midi;
+  GThread *thread;
+  /* Mutex for the player thread */
+  GMutex *mutex;
+  /* Kill player flag (the mutex must be used when accessing) */
+  unsigned int killthread;
+  /* MIDI data structure */
+  struct midi *midi;
+  /* RTC device file descriptor */
+  int rtc;
+  /* Editor for this player */
   struct editor *editor;
 };
 
@@ -94,4 +108,11 @@ void player_reset_pitch(struct player *);
 /* Reallocate track status array */
 void player_trackstatus_create(struct player *, int);
 
+/* Set player position */
+void player_set_section(struct player *, int);
+void player_set_playseq(struct player *, int);
+void player_set_position(struct player *, int);
+void player_set_block(struct player *, int);
+void player_set_line(struct player *, int);
+
 #endif
