@@ -22,27 +22,26 @@
 #ifndef _SONG_H
 #define _SONG_H
 
-#include "mmd.h"
 #include "playseq.h"
 #include "block.h"
 #include "instrument.h"
 #include "midi.h"
 
 enum {
-  COMMAND_PREVIOUS_COMMAND_VALUE=0x00,
-  COMMAND_PITCH_WHEEL=0x01,
-  COMMAND_END_BLOCK=0x02,
-  COMMAND_PLAYSEQ_POSITION=0x03,
-  COMMAND_SEND_SYSEX=0x08,
-  COMMAND_HOLD=0x09,
-  COMMAND_RETRIGGER=0x0a,
-  COMMAND_DELAY=0x0b,
-  COMMAND_VELOCITY=0x0c,
-  COMMAND_CHANNEL_PRESSURE=0x0d,
-  COMMAND_TPL=0x0e,
-  COMMAND_TEMPO=0x0f,
-  COMMAND_NOT_DEFINED=0x10,
-  COMMAND_MIDI_CONTROLLERS=0x80
+  COMMAND_PREVIOUS_COMMAND_VALUE = 0x00,
+  COMMAND_PITCH_WHEEL = 0x01,
+  COMMAND_END_BLOCK = 0x02,
+  COMMAND_PLAYSEQ_POSITION = 0x03,
+  COMMAND_SEND_MESSAGE = 0x08,
+  COMMAND_HOLD = 0x09,
+  COMMAND_RETRIGGER = 0x0a,
+  COMMAND_DELAY = 0x0b,
+  COMMAND_VELOCITY = 0x0c,
+  COMMAND_CHANNEL_PRESSURE = 0x0d,
+  COMMAND_TPL = 0x0e,
+  COMMAND_TEMPO = 0x0f,
+  COMMAND_NOT_DEFINED = 0x10,
+  COMMAND_MIDI_CONTROLLERS = 0x80
 };
 
 struct song {
@@ -73,9 +72,9 @@ struct song {
   /* Master volume */
   unsigned int mastervolume;
   /* Number of System Exclusive messages */
-  unsigned int numsysexes;
+  unsigned int nummessages;
   /* System Exclusive messages */
-  struct sysex **sysexes;
+  struct message **messages;
   /* Whether to send MIDI sync or not */
   unsigned int sendsync;
 };
@@ -96,10 +95,10 @@ void song_delete_playseq(struct song *, int);
 void song_insert_section(struct song *, int);
 /* Deletes a section from the given position of the section array */
 void song_delete_section(struct song *, int);
-/* Inserts a new SysEx in the SysEx array in the given position */
-void song_insert_sysex(struct song *, int);
-/* Deletes a SysEx from the given position of the SysEx array */
-void song_delete_sysex(struct song *, int);
+/* Inserts a new Message in the Message array in the given position */
+void song_insert_message(struct song *, int);
+/* Deletes a Message from the given position of the Message array */
+void song_delete_message(struct song *, int);
 /* Sets a section in the given position to point somewhere */
 void song_set_section(struct song *, int, int);
 /* Sets the number of ticks per line for a song */
@@ -110,10 +109,6 @@ void song_set_tempo(struct song *, unsigned int);
 int song_check_maxtracks(struct song *);
 /* Make sure the instrument exists; add instruments if necessary */
 void song_check_instrument(struct song *, int);
-/* Converts an MMD2 module to a song */
-struct song *song_convert_MMD2(struct MMD2 *);
-/* Converts MMD command values at given location */
-void song_convert_commands(unsigned char *, struct MMDMIDICmd3x *);
 /* Loads a song from an XML file */
 struct song *song_load(char *);
 /* Parses a song element in an XML file */
