@@ -32,6 +32,7 @@
 #include "player.h"
 #include "trackerwidget.h"
 #include "gui.h"
+#include "conversion.h"
 
 void on_menuitem_file_new_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
@@ -54,8 +55,16 @@ void on_menuitem_file_open_activate(GtkMenuItem * menuitem, gpointer user_data)
 void on_menuitem_file_save_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
   struct gui *gui = (struct gui *)user_data;
-
-  song_save(gui->editor->song, gui->editor->filename);
+  int l;
+  
+  /* Save in the format determined by the filename extension */
+  l=strlen(gui->editor->filename);
+  if(l>4 && (strcasecmp(gui->editor->filename+l-3, "med")==0 || strcasecmp(gui->editor->filename+l-3, "mmd")==0 || strcasecmp(gui->editor->filename+l-4, "mmd2")==0)) {
+    struct MMD2 *mmd=song_convert(gui->editor->song);
+    MMD2_save(mmd, gui->editor->filename);
+    MMD2_free(mmd);
+  } else
+    song_save(gui->editor->song, gui->editor->filename);
 }
 
 void on_menuitem_file_saveas_activate(GtkMenuItem * menuitem, gpointer user_data)
@@ -87,6 +96,8 @@ void on_menuitem_edit_cut_activate(GtkMenuItem * menuitem, gpointer user_data)
   struct gui *gui = (struct gui *)user_data;
   Tracker *tracker = (Tracker *) glade_xml_get_widget(gui->xml, "tracker");
 
+  if(tracker_is_in_selection_mode(tracker))
+    tracker_mark_selection(tracker, FALSE);
   if (gui->editor->copyarea)
     block_free(gui->editor->copyarea);
   gui->editor->copyarea = block_copy(gui->editor->song->blocks[gui->editor->block], tracker->sel_start_ch, tracker->sel_start_row, tracker->sel_end_ch, tracker->sel_end_row);
@@ -99,6 +110,8 @@ void on_menuitem_edit_copy_activate(GtkMenuItem * menuitem, gpointer user_data)
   struct gui *gui = (struct gui *)user_data;
   Tracker *tracker = (Tracker *) glade_xml_get_widget(gui->xml, "tracker");
 
+  if(tracker_is_in_selection_mode(tracker))
+    tracker_mark_selection(tracker, FALSE);
   if (gui->editor->copyarea)
     block_free(gui->editor->copyarea);
   gui->editor->copyarea = block_copy(gui->editor->song->blocks[gui->editor->block], tracker->sel_start_ch, tracker->sel_start_row, tracker->sel_end_ch, tracker->sel_end_row);
@@ -480,10 +493,10 @@ void on_menuitem_track_changeinstrument_activate(GtkMenuItem * menuitem, gpointe
   }
 }
 
-void on_menuitem_song_sysexlist_activate(GtkMenuItem * menuitem, gpointer user_data)
+void on_menuitem_song_messagelist_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
   struct gui *gui = (struct gui *)user_data;
-  GtkWidget *window = glade_xml_get_widget(gui->xml, "dialog_sysex");
+  GtkWidget *window = glade_xml_get_widget(gui->xml, "dialog_message");
 
   if (!GTK_WIDGET_VISIBLE(window))
     gtk_widget_show(window);
@@ -535,7 +548,7 @@ void on_menuitem_about_activate(GtkMenuItem * menuitem, gpointer user_data)
     return;
   }
 
-  gui->window_about = gnome_about_new("Tutka", VERSION, "Copyright \xc2\xa9 2002-2003 Vesa Halttunen", "http://www.freesoftware.fsf.org/tutka/", (const gchar **)authors, (const gchar **)authors, NULL, NULL);
+  gui->window_about = gnome_about_new("Tutka", VERSION, "Copyright \xc2\xa9 2002-2003 Vesa Halttunen", "http://www.nongnu.org/tutka/", (const gchar **)authors, (const gchar **)authors, NULL, NULL);
 
   gtk_window_set_destroy_with_parent(GTK_WINDOW(gui->window_about), TRUE);
   g_signal_connect(G_OBJECT(gui->window_about), "destroy", G_CALLBACK(gtk_widget_destroyed), &gui->window_about);
@@ -696,7 +709,7 @@ gboolean on_label_timer_button_press_event(GtkWidget * widget, GdkEventButton *
   return FALSE;
 }
 
-void on_selection_sysexlist_changed(GtkTreeSelection * selection, gpointer user_data)
+void on_selection_messagelist_changed(GtkTreeSelection * selection, gpointer user_data)
 {
   struct gui *gui = (struct gui *)user_data;
   GtkTreeIter iter;
@@ -704,53 +717,53 @@ void on_selection_sysexlist_changed(GtkTreeSelection * selection, gpointer user_
 
   /* Get the selected row */
   if (gtk_tree_selection_get_selected(selection, &model, &iter))
-    gtk_tree_model_get(model, &iter, 0, &gui->sysexlist_sysex, -1);
+    gtk_tree_model_get(model, &iter, 0, &gui->messagelist_message, -1);
 
-  gui_sysexlist_refresh(gui, FALSE);
+  gui_messagelist_refresh(gui, FALSE);
 }
 
-void on_button_sysex_appendnew_clicked(GtkButton * button, gpointer user_data)
+void on_button_message_appendnew_clicked(GtkButton * button, gpointer user_data)
 {
   struct gui *gui = (struct gui *)user_data;
-  song_insert_sysex(gui->editor->song, gui->editor->song->numsysexes);
-  gui_sysexlist_refresh(gui, TRUE);
+  song_insert_message(gui->editor->song, gui->editor->song->nummessages);
+  gui_messagelist_refresh(gui, TRUE);
 }
 
-void on_button_sysex_delete_clicked(GtkButton * button, gpointer user_data)
+void on_button_message_delete_clicked(GtkButton * button, gpointer user_data)
 {
   struct gui *gui = (struct gui *)user_data;
-  if (gui->sysexlist_sysex != -1) {
-    song_delete_sysex(gui->editor->song, gui->sysexlist_sysex);
-    gui_sysexlist_refresh(gui, TRUE);
+  if (gui->messagelist_message != -1) {
+    song_delete_message(gui->editor->song, gui->messagelist_message);
+    gui_messagelist_refresh(gui, TRUE);
   }
 }
 
-void on_button_sysex_insertnew_clicked(GtkButton * button, gpointer user_data)
+void on_button_message_insertnew_clicked(GtkButton * button, gpointer user_data)
 {
   struct gui *gui = (struct gui *)user_data;
-  song_insert_sysex(gui->editor->song, gui->sysexlist_sysex);
-  if (gui->sysexlist_sysex == -1)
-    gui->sysexlist_sysex = 0;
-  gui_sysexlist_refresh(gui, TRUE);
+  song_insert_message(gui->editor->song, gui->messagelist_message);
+  if (gui->messagelist_message == -1)
+    gui->messagelist_message = 0;
+  gui_messagelist_refresh(gui, TRUE);
 }
 
-void on_button_sysex_send_clicked(GtkButton * button, gpointer user_data)
+void on_button_message_send_clicked(GtkButton * button, gpointer user_data)
 {
   struct gui *gui = (struct gui *)user_data;
-  if (gui->sysexlist_sysex != -1) {
-    midi_system_exclusive(gui->editor->player->midi, gui->editor->song->sysexes[gui->sysexlist_sysex]->data, gui->editor->song->sysexes[gui->sysexlist_sysex]->length);
+  if (gui->messagelist_message != -1) {
+    midi_write(gui->editor->player->midi, gui->editor->song->messages[gui->messagelist_message]->data, gui->editor->song->messages[gui->messagelist_message]->length);
   }
 }
 
-void on_button_sysex_receive_clicked(GtkButton * button, gpointer user_data)
+void on_button_message_receive_clicked(GtkButton * button, gpointer user_data)
 {
   struct gui *gui = (struct gui *)user_data;
-  if (gui->sysexlist_sysex != -1) {
-    midi_read_system_exclusive(gui->editor->player->midi, gui->editor->song->sysexes[gui->sysexlist_sysex], gui->sysexlist_autostop);
+  if (gui->messagelist_message != -1) {
+    midi_read_system_exclusive(gui->editor->player->midi, gui->editor->song->messages[gui->messagelist_message], gui->messagelist_autostop);
   }
 }
 
-void on_checkbutton_sysex_autostop_toggled(GtkToggleButton * togglebutton, gpointer user_data)
+void on_checkbutton_message_autostop_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
 
 }
@@ -1035,17 +1048,17 @@ gboolean on_entry_blocklist_focus_out_event(GtkWidget * widget, GdkEventFocus *
   return FALSE;
 }
 
-gboolean on_entry_sysex_name_focus_out_event(GtkWidget * widget, GdkEventFocus * event, gpointer user_data)
+gboolean on_entry_message_name_focus_out_event(GtkWidget * widget, GdkEventFocus * event, gpointer user_data)
 {
   struct gui *gui = (struct gui *)user_data;
-  if (gui->sysexlist_sysex != -1) {
+  if (gui->messagelist_message != -1) {
     char *name = (char *)gtk_entry_get_text(GTK_ENTRY(widget));
 
-    if (gui->editor->song->sysexes[gui->sysexlist_sysex]->name)
-      free(gui->editor->song->sysexes[gui->sysexlist_sysex]->name);
+    if (gui->editor->song->messages[gui->messagelist_message]->name)
+      free(gui->editor->song->messages[gui->messagelist_message]->name);
 
-    gui->editor->song->sysexes[gui->sysexlist_sysex]->name = (char *)strdup(name);
-    gui_sysexlist_refresh(gui, TRUE);
+    gui->editor->song->messages[gui->messagelist_message]->name = (char *)strdup(name);
+    gui_messagelist_refresh(gui, TRUE);
   }
 
   return FALSE;
@@ -1082,9 +1095,9 @@ gboolean on_entry_instrumentproperties_name_focus_out_event(GtkWidget * widget,
   return FALSE;
 }
 
-void on_button_sysex_close_clicked(GtkButton * button, gpointer user_data)
+void on_button_message_close_clicked(GtkButton * button, gpointer user_data)
 {
-  on_menuitem_song_sysexlist_activate(NULL, user_data);
+  on_menuitem_song_messagelist_activate(NULL, user_data);
 }
 
 void on_button_saveas_ok_clicked(GtkButton * button, gpointer user_data)
@@ -1092,14 +1105,21 @@ void on_button_saveas_ok_clicked(GtkButton * button, gpointer user_data)
   struct gui *gui = (struct gui *)user_data;
   GtkWidget *fs = glade_xml_get_widget(gui->xml, "fileselection_saveas");
   gchar *path;
+  int l;
   
   /* Store the filename */
   if (gui->editor->filename != NULL)
     free(gui->editor->filename);
   gui->editor->filename = strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs)));
 
-  /* Save... */
-  song_save(gui->editor->song, gui->editor->filename);
+  /* Save in the format determined by the filename extension */
+  l=strlen(gui->editor->filename);
+  if(l>4 && (strcasecmp(gui->editor->filename+l-3, "med")==0 || strcasecmp(gui->editor->filename+l-3, "mmd")==0 || strcasecmp(gui->editor->filename+l-4, "mmd2")==0)) {
+    struct MMD2 *mmd=song_convert(gui->editor->song);
+    MMD2_save(mmd, gui->editor->filename);
+    MMD2_free(mmd);
+  } else
+    song_save(gui->editor->song, gui->editor->filename);
 
   /* Store the path in GConf for further use */
   path=g_path_get_dirname(gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs)));
@@ -1149,11 +1169,11 @@ void on_button_saveas_cancel_clicked(GtkButton * button, gpointer user_data)
   gtk_widget_hide(fs);
 }
 
-void on_spinbutton_sysex_length_changed(GtkEditable * editable, gpointer user_data)
+void on_spinbutton_message_length_changed(GtkEditable * editable, gpointer user_data)
 {
   struct gui *gui = (struct gui *)user_data;
-  if (gui->sysexlist_sysex != -1)
-    sysex_set_length(gui->editor->song->sysexes[gui->sysexlist_sysex], (unsigned int)gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(editable))->value);
+  if (gui->messagelist_message != -1)
+    message_set_length(gui->editor->song->messages[gui->messagelist_message], (unsigned int)gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(editable))->value);
 }
 
 gboolean on_entry_songname_focus_out_event(GtkWidget * widget, GdkEventFocus * event, gpointer user_data)
@@ -1422,14 +1442,14 @@ void on_checkbutton_sendsync_toggled(GtkToggleButton * togglebutton, gpointer us
     gui->editor->song->sendsync = 0;
 }
 
-void on_checkbutton_sysex_autosend_toggled(GtkToggleButton * togglebutton, gpointer user_data)
+void on_checkbutton_message_autosend_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 {
   struct gui *gui = (struct gui *)user_data;
-  if (gui->sysexlist_sysex != -1) {
+  if (gui->messagelist_message != -1) {
     if (gtk_toggle_button_get_active(togglebutton))
-      sysex_set_autosend(gui->editor->song->sysexes[gui->sysexlist_sysex], 1);
+      message_set_autosend(gui->editor->song->messages[gui->messagelist_message], 1);
     else
-      sysex_set_autosend(gui->editor->song->sysexes[gui->sysexlist_sysex], 0);
+      message_set_autosend(gui->editor->song->messages[gui->messagelist_message], 0);
   }
 }
 
