@@ -21,7 +21,7 @@
 
 #include <stdio.h>
 #include <string.h>
-#include "song.h"
+#include "conversion.h"
 #include "editor.h"
 #include "player.h"
 #include "callbacks.h"
@@ -70,8 +70,26 @@ void editor_song_open(struct editor *editor, char *filename)
 
   /* If a filename was supplied open the file */
   if (filename != NULL) {
+    FILE *file=fopen(filename, "r");
+    unsigned char data[4]={ 0, 0, 0, 0 };
+    
     editor->filename = strdup(filename);
-    editor->song = song_load(filename);
+
+    /* Read first four bytes for checking the file type */
+    if(file!=NULL) {
+      fread(data, sizeof(unsigned char), 4, file);
+      fclose(file);
+    }
+
+    /* Is it an MMD2 file? */
+    if(data[0]==(ID_MMD2>>24) && data[1]==((ID_MMD2>>16)&0xff) && data[2]==((ID_MMD2>>8)&0xff) && data[3]==(ID_MMD2&0xff)) {
+      struct MMD2 *mmd;
+      mmd = MMD2_load(filename);
+      editor->song = MMD2_convert(mmd);
+      MMD2_free(mmd);
+    } else
+      editor->song = song_load(filename);
+
     /* Just allocate a new song if the song couldn't be opened */
     if (editor->song == NULL)
       editor->song = song_alloc();
