@@ -127,15 +127,15 @@ struct gui *gui_open(struct editor *editor, char *filename)
   gtk_tree_view_append_column(treeview, new_column("Block Number", renderer, "text", 0, NULL));
   gtk_tree_view_append_column(treeview, new_column("Block Name", renderer, "text", 1, NULL));
 
-  /* SysEx List */
-  gui->store_sysexlist = gtk_list_store_new(2, G_TYPE_INT, G_TYPE_STRING);
-  treeview = GTK_TREE_VIEW(glade_xml_get_widget(gui->xml, "treeview_sysexlist"));
+  /* Message List */
+  gui->store_messagelist = gtk_list_store_new(2, G_TYPE_INT, G_TYPE_STRING);
+  treeview = GTK_TREE_VIEW(glade_xml_get_widget(gui->xml, "treeview_messagelist"));
   select = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
   gtk_tree_selection_set_mode(select, GTK_SELECTION_SINGLE);
-  g_signal_connect(G_OBJECT(select), "changed", G_CALLBACK(on_selection_sysexlist_changed), gui);
-  gtk_tree_view_set_model(treeview, GTK_TREE_MODEL(gui->store_sysexlist));
-  gtk_tree_view_append_column(treeview, new_column("Sysex Number", renderer, "text", 0, NULL));
-  gtk_tree_view_append_column(treeview, new_column("Sysex Name", renderer, "text", 1, NULL));
+  g_signal_connect(G_OBJECT(select), "changed", G_CALLBACK(on_selection_messagelist_changed), gui);
+  gtk_tree_view_set_model(treeview, GTK_TREE_MODEL(gui->store_messagelist));
+  gtk_tree_view_append_column(treeview, new_column("Message Number", renderer, "text", 0, NULL));
+  gtk_tree_view_append_column(treeview, new_column("Message Name", renderer, "text", 1, NULL));
 
   /* Set the keyboard octave */
   gtk_option_menu_set_history(GTK_OPTION_MENU(glade_xml_get_widget(gui->xml, "optionmenu_keyboard")), 3);
@@ -175,7 +175,7 @@ void gui_refresh_all(struct gui *gui)
   gui_playseq_refresh(gui, TRUE);
   gui_sectionlist_refresh(gui, TRUE);
   gui_instrument_refresh(gui, TRUE);
-  gui_sysexlist_refresh(gui, TRUE);
+  gui_messagelist_refresh(gui, TRUE);
   gui_trackvolumes_refresh(gui);
   gui_song_refresh(gui);
 
@@ -309,9 +309,9 @@ void gui_refresh(struct gui *gui)
   g_thread_yield();
 
   g_mutex_lock(gui->refresh_mutex);
-  if (gui->refresh_mask & GUI_REFRESH_SYSEXLIST) {
-    gui_sysexlist_refresh(gui, FALSE);
-    gui->refresh_mask ^= GUI_REFRESH_SYSEXLIST;
+  if (gui->refresh_mask & GUI_REFRESH_MESSAGELIST) {
+    gui_messagelist_refresh(gui, FALSE);
+    gui->refresh_mask ^= GUI_REFRESH_MESSAGELIST;
   }
   g_mutex_unlock(gui->refresh_mutex);
   g_thread_yield();
@@ -596,6 +596,8 @@ void gui_playseq_refresh(struct gui *gui, gboolean recreate)
   gtk_tree_selection_select_path(gtk_tree_view_get_selection(treeview), treepath);
   gtk_tree_view_scroll_to_cell(treeview, treepath, NULL, TRUE, 0.5, 0);
   gtk_tree_view_set_cursor(treeview, treepath, NULL, FALSE);
+
+  gui_playseq_info_refresh(gui);
 }
 
 /* Refresh section list buttons */
@@ -647,47 +649,47 @@ void gui_sectionlist_refresh(struct gui *gui, gboolean recreate)
   gui_sectionlist_buttons_refresh(gui);
 }
 
-void gui_sysexlist_refresh(struct gui *gui, gboolean recreate)
+void gui_messagelist_refresh(struct gui *gui, gboolean recreate)
 {
-  /* Refresh the sysex list widgets */
+  /* Refresh the message list widgets */
   int i;
-  char oldsysex[10], sysex[6 + 8];
+  char oldmessage[10], message[6 + 8];
 
-  if (gui->editor->song->numsysexes == 0)
-    gui->sysexlist_sysex = -1;
+  if (gui->editor->song->nummessages == 0)
+    gui->messagelist_message = -1;
 
-  snprintf(oldsysex, 10, "%d", gui->sysexlist_sysex);
+  snprintf(oldmessage, 10, "%d", gui->messagelist_message);
 
   if (recreate) {
-    /* Recreate the SysEx list */
-    gtk_list_store_clear(gui->store_sysexlist);
-    for (i = 0; i < gui->editor->song->numsysexes; i++) {
+    /* Recreate the Message list */
+    gtk_list_store_clear(gui->store_messagelist);
+    for (i = 0; i < gui->editor->song->nummessages; i++) {
       GtkTreeIter iter;
-      gtk_list_store_append(gui->store_sysexlist, &iter);
-      gtk_list_store_set(gui->store_sysexlist, &iter, 0, i, 1, gui->editor->song->sysexes[i]->name, -1);
+      gtk_list_store_append(gui->store_messagelist, &iter);
+      gtk_list_store_set(gui->store_messagelist, &iter, 0, i, 1, gui->editor->song->messages[i]->name, -1);
     }
   }
 
-  /* Move back to the previously selected SysEx and make widgets sensitive */
-  if (gui->sysexlist_sysex != -1) {
-    gtk_tree_selection_select_path(gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gui->xml, "treeview_sysexlist"))), gtk_tree_path_new_from_string(oldsysex));
+  /* Move back to the previously selected Message and make widgets sensitive */
+  if (gui->messagelist_message != -1) {
+    gtk_tree_selection_select_path(gtk_tree_view_get_selection(GTK_TREE_VIEW(glade_xml_get_widget(gui->xml, "treeview_messagelist"))), gtk_tree_path_new_from_string(oldmessage));
 
-    /* Show the number of the selected SysEx message */
-    snprintf(sysex, 6 + 8, "SysEx %d/%d", gui->sysexlist_sysex + 1, gui->editor->song->numsysexes);
-    gtk_frame_set_label(GTK_FRAME(glade_xml_get_widget(gui->xml, "frame_sysex_controls")), sysex);
-    gtk_spin_button_set_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gui->xml, "spinbutton_sysex_length")), gui->editor->song->sysexes[gui->sysexlist_sysex]->length);
-    gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "table_sysex1"), TRUE);
-    gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "button_sysex_send"), TRUE);
-    gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "button_sysex_receive"), TRUE);
-    /* gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "checkbutton_sysex_autostop"), TRUE); */
-    gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "button_sysex_delete"), TRUE);
+    /* Show the number of the selected Message message */
+    snprintf(message, 6 + 8, "Message %d/%d", gui->messagelist_message + 1, gui->editor->song->nummessages);
+    gtk_frame_set_label(GTK_FRAME(glade_xml_get_widget(gui->xml, "frame_message_controls")), message);
+    gtk_spin_button_set_value(GTK_SPIN_BUTTON(glade_xml_get_widget(gui->xml, "spinbutton_message_length")), gui->editor->song->messages[gui->messagelist_message]->length);
+    gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "table_message1"), TRUE);
+    gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "button_message_send"), TRUE);
+    gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "button_message_receive"), TRUE);
+    /* gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "checkbutton_message_autostop"), TRUE); */
+    gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "button_message_delete"), TRUE);
   } else {
-    gtk_frame_set_label(GTK_FRAME(glade_xml_get_widget(gui->xml, "frame_sysex_controls")), "SysEx 0/0");
-    gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "table_sysex1"), FALSE);
-    gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "button_sysex_send"), FALSE);
-    gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "button_sysex_receive"), FALSE);
-    /* gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "checkbutton_sysex_autostop"), FALSE); */
-    gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "button_sysex_delete"), FALSE);
+    gtk_frame_set_label(GTK_FRAME(glade_xml_get_widget(gui->xml, "frame_message_controls")), "Message 0/0");
+    gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "table_message1"), FALSE);
+    gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "button_message_send"), FALSE);
+    gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "button_message_receive"), FALSE);
+    /* gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "checkbutton_message_autostop"), FALSE); */
+    gtk_widget_set_sensitive(glade_xml_get_widget(gui->xml, "button_message_delete"), FALSE);
   }
 }
 
