@@ -45,14 +45,17 @@ void instrument_free(struct instrument *instrument) {
 /* Parses an instrument element in an XML file */
 struct instrument *instrument_parse(xmlDocPtr doc, xmlNsPtr ns, xmlNodePtr cur) {
   struct instrument *instrument=NULL;
-  
+
   if((!xmlStrcmp(cur->name, "instrument")) && (cur->ns==ns)) {
     char *prop;
     xmlNodePtr temp=cur->xmlChildrenNode;
 
     /* Allocate instrument */
     instrument=(struct instrument *)calloc(1, sizeof(struct instrument));
-    instrument->name=strdup(temp->content);
+    if(temp!=NULL)
+      instrument->name=strdup(temp->content);
+    else
+      instrument->name=(char *)calloc(1, sizeof(char));
     prop=xmlGetProp(cur, "midipreset");
     if(prop!=NULL)
       instrument->midipreset=atoi(prop);
@@ -68,7 +71,7 @@ struct instrument *instrument_parse(xmlDocPtr doc, xmlNsPtr ns, xmlNodePtr cur)
     prop=xmlGetProp(cur, "hold");
     if(prop!=NULL)
       instrument->hold=atoi(prop);
-  } else
+  } else if(cur->type!=XML_COMMENT_NODE)
     fprintf(stderr, "XML error: expected instrument, got %s\n", cur->name);
 
   return instrument;
