@@ -70,30 +70,6 @@ gboolean keyboard_event(GtkWidget *widget, GdkEventKey *event,
 	    tracker_mark_selection(tracker, TRUE);
 	  handled=TRUE;
 	  break;
-	case 'c':
-	  /* CTRL-C: Copy selection */
-	  if(tracker_is_in_selection_mode(tracker))
-	    tracker_mark_selection(tracker, FALSE);
-	  on_menuitem_edit_copy_activate(NULL, gui);
-	  handled=TRUE;
-	  break;
-	case 'x':
-	  /* CTRL-X: Cut selection */
-	  if(tracker_is_in_selection_mode(tracker))
-	    tracker_mark_selection(tracker, FALSE);
-	  on_menuitem_edit_cut_activate(NULL, gui);
-	  handled=TRUE;
-	  break;
-	case 'v':
-	  /* CTRL-V: Paste selection */
-	  on_menuitem_edit_paste_activate(NULL, gui);
-	  handled=TRUE;
-	  break;
-	case 'q':
-	  /* CTRL-Q: Quit */
-	  handled=TRUE;
-	  gtk_main_quit();
-	  break;
 	case 'k':
 	  /* CTRL-K: Clear until the end of the track */
 	  block_clear(song->blocks[editor->block],
@@ -103,26 +79,6 @@ gboolean keyboard_event(GtkWidget *widget, GdkEventKey *event,
 	  tracker_redraw(tracker);
 	  handled=TRUE;
 	  break;
-	case 's':
-	  /* CTRL-S: Save song */
-	  song_save(song, editor->filename);
-	  handled=TRUE;
-	  break;
-	case GDK_F3:
-	  /* CTRL-F3: Cut block */
-	  on_menuitem_block_cut_activate(NULL, gui);
-	  handled=TRUE;
-	  break;
-	case GDK_F4:
-	  /* CTRL-F4: Copy block */
-	  on_menuitem_block_copy_activate(NULL, gui);
-	  handled=TRUE;
-	  break;
-	case GDK_F5:
-	  /* CTRL-F5: Paste block */
-	  on_menuitem_block_paste_activate(NULL, gui);
-	  handled=TRUE;
-	  break;
 	case GDK_Left:
 	  /* CTRL-Left: Previous instrument */
 	  if(editor->instrument>0) {
@@ -168,21 +124,6 @@ gboolean keyboard_event(GtkWidget *widget, GdkEventKey *event,
 	}
       } else if(shift) {
 	switch (event->keyval) {
-	case GDK_F3:
-	  /* Shift-F3: Cut track */
-	  on_menuitem_track_cut_activate(NULL, gui);
-	  handled=TRUE;
-	  break;
-	case GDK_F4:
-	  /* Shift-F4: Copy track */
-	  on_menuitem_track_copy_activate(NULL, gui);
-	  handled=TRUE;
-	  break;
-	case GDK_F5:
-	  /* Shift-F5: Paste track */
-	  on_menuitem_track_paste_activate(NULL, gui);
-	  handled=TRUE;
-	  break;
 	case GDK_Left:
 	  /* Shift-Left: Next position */
 	  if(editor->position>0)
