@@ -179,24 +179,15 @@ void midi_pitch_wheel(struct midi *midi, unsigned char channel,
   fsync(midi->fd);
 }
 
-/* Sends a MIDI SysEX message */
-void midi_system_exclusive(struct midi *midi, unsigned char *message,
-			   unsigned short length) {
-  unsigned char *data=(unsigned char *)calloc(length+2, sizeof(unsigned char));
-
+/* Sends an arbitrary MIDI message */
+void midi_write(struct midi *midi, unsigned char *message, unsigned short length) {
   if(midi==NULL) {
-    fprintf(stderr, "midi_system_exclusive() called with null midi\n");
+    fprintf(stderr, "midi_write() called with null midi\n");
     return;
   }
 
-  data[0]=0xf0;
-  memcpy(data+1, message, length);
-  data[length+1]=0xf7;
-  
-  write(midi->fd, data, length+2);
+  write(midi->fd, message, length+2);
   fsync(midi->fd);
-
-  free(data);
 }
 
 /* Send a clock message */
@@ -250,8 +241,8 @@ unsigned char *midi_read(struct midi *midi) {
   return NULL;
 }
 
-/* Receives a MIDI SysEx message */
-void midi_read_system_exclusive(struct midi *midi, struct sysex *sysex,
+/* Receives a MIDI message */
+void midi_read_system_exclusive(struct midi *midi, struct message *message,
 				int autostop) {
   int status=0, i=0;
   unsigned char c=0;
@@ -261,61 +252,64 @@ void midi_read_system_exclusive(struct midi *midi, struct sysex *sysex,
     return;
   }
 
-  if(sysex==NULL) {
-    fprintf(stderr, "midi_read_system_exclusive() called with null sysex\n");
+  if(message==NULL) {
+    fprintf(stderr, "midi_read_system_exclusive() called with null message\n");
     return;
   }
-    
-  /* Read until a SysEx dump begins */
+
+  /* Read until a dump begins */
   while(c!=0xf0) {
     usleep(40);
     status=read(midi->fd, &c, 1);
   }
+
+  /* Store the first byte */
+  message->data[i++]=c;
   
   /* Read until the buffer is full or to the end of the SysEx (autostop) */
-  while(i<sysex->length) {
+  while(i<message->length) {
     status=read(midi->fd, &c, 1);
     
     if(status==1) {
-      sysex->data[i++]=c;
-      if(autostop==1 && sysex->data[i-1]==0xf7)
+      message->data[i++]=c;
+      if(autostop==1 && c==0xf7)
 	break;
     }
   }
   
   /* Remove unnecessary bytes if necessary */
-  if(i<sysex->length) {
-    sysex->length=i;
-    sysex->data=(unsigned char *)realloc(sysex->data, sysex->length);
+  if(i<message->length) {
+    message->length=i;
+    message->data=(unsigned char *)realloc(message->data, message->length);
   }
 }
 
-/* Sets the length of a MIDI SysEx message */
-void sysex_set_length(struct sysex *sysex, unsigned int length) {
-  if(sysex==NULL) {
-    fprintf(stderr, "sysex_set_length() called with null sysex\n");
+/* Sets the length of a MIDI message */
+void message_set_length(struct message *message, unsigned int length) {
+  if(message==NULL) {
+    fprintf(stderr, "message_set_length() called with null message\n");
     return;
   }
 
-  sysex->length=length;
-  sysex->data=(unsigned char *)realloc(sysex->data, sysex->length);
+  message->length=length;
+  message->data=(unsigned char *)realloc(message->data, message->length);
 }
 
-/* Sets the autosend flag of a MIDI SysEx message */
-void sysex_set_autosend(struct sysex *sysex, unsigned int autosend) {
-  if(sysex==NULL) {
-    fprintf(stderr, "sysex_set_autosend() called with null sysex\n");
+/* Sets the autosend flag of a MIDI message */
+void message_set_autosend(struct message *message, unsigned int autosend) {
+  if(message==NULL) {
+    fprintf(stderr, "message_set_autosend() called with null message\n");
     return;
   }
 
-  sysex->autosend=autosend;
+  message->autosend=autosend;
 }
 
-/* Parses a SysEx element in an XML file */
-struct sysex *sysex_parse(xmlDocPtr doc, xmlNsPtr ns, xmlNodePtr cur) {
-  struct sysex *sysex=NULL;
+/* Parses a message element in an XML file */
+struct message *message_parse(xmlDocPtr doc, xmlNsPtr ns, xmlNodePtr cur) {
+  struct message *message=NULL;
   
-  if((!xmlStrcmp(cur->name, "sysex")) && (cur->ns==ns)) {
+  if((!xmlStrcmp(cur->name, "message")) && (cur->ns==ns)) {
     xmlNodePtr temp=cur->xmlChildrenNode;
     char c[3], *prop;
     int i;
@@ -324,46 +318,46 @@ struct sysex *sysex_parse(xmlDocPtr doc, xmlNsPtr ns, xmlNodePtr cur) {
     /* Temporary string for hexadecimal parsing */
     c[2]=0;
 
-    /* Allocate sysex */
-    sysex=(struct sysex *)calloc(1, sizeof(struct sysex));
-    sysex->name=xmlGetProp(cur, "name");
-    sysex->length=strlen(temp->content)/2;
+    /* Allocate message */
+    message=(struct message *)calloc(1, sizeof(struct message));
+    message->name=xmlGetProp(cur, "name");
+    message->length=strlen(temp->content)/2;
     prop=xmlGetProp(cur, "autosend");
     if(prop!=NULL)
-      sysex->autosend=atoi(prop);
-    sysex->data=(unsigned char *)calloc(sysex->length, sizeof(unsigned char));
-    for(i=0; i<sysex->length; i++) {
+      message->autosend=atoi(prop);
+    message->data=(unsigned char *)calloc(message->length, sizeof(unsigned char));
+    for(i=0; i<message->length; i++) {
       c[0]=temp->content[i*2];
       c[1]=temp->content[i*2+1];
       sscanf(c, "%X", &d);
-      sysex->data[i]=d;
+      message->data[i]=d;
     }
   } else if(cur->type!=XML_COMMENT_NODE)
-    fprintf(stderr, "XML error: expected sysex, got %s\n", cur->name);
+    fprintf(stderr, "XML error: expected message, got %s\n", cur->name);
 
-  return sysex;
+  return message;
 }
 
-/* Saves a SysEx message to an XML file */
-void sysex_save(struct sysex *sysex, int number, xmlNodePtr parent) {
+/* Saves a message to an XML file */
+void message_save(struct message *message, int number, xmlNodePtr parent) {
   char *c, t[10];
   xmlNodePtr node;
   int i;
 
-  if(sysex==NULL) {
-    fprintf(stderr, "sysex_save() called with null sysex\n");
+  if(message==NULL) {
+    fprintf(stderr, "message_save() called with null message\n");
     return;
   }
 
-  c=(char *)calloc(2*sysex->length+1, sizeof(char));
-  for(i=0; i<sysex->length; i++)
-    sprintf(c+(i*2), "%.2X", sysex->data[i]);
+  c=(char *)calloc(2*message->length+1, sizeof(char));
+  for(i=0; i<message->length; i++)
+    sprintf(c+(i*2), "%.2X", message->data[i]);
 
-  node=xmlNewChild(parent, NULL, "sysex", c);
+  node=xmlNewChild(parent, NULL, "message", c);
   snprintf(t, 10, "%d", number);
   xmlSetProp(node, "number", t);
-  xmlSetProp(node, "name", sysex->name);
-  snprintf(t, 10, "%d", sysex->autosend);
+  xmlSetProp(node, "name", message->name);
+  snprintf(t, 10, "%d", message->autosend);
   xmlSetProp(node, "autosend", t);
 
   xmlAddChild(parent, xmlNewText("\n"));
