@@ -354,10 +354,10 @@ static void player_thread(struct player *player)
 	      postvalue = value;
 	    }
 	    break;
-	  case COMMAND_SEND_SYSEX:
+	  case COMMAND_SEND_MESSAGE:
 	    /* Only on first tick */
-	    if (player->tick == 0 && value < song->numsysexes)
-	      midi_system_exclusive(player->midi, song->sysexes[value]->data, song->sysexes[value]->length);
+	    if (player->tick == 0 && value < song->nummessages)
+	      midi_write(player->midi, song->messages[value]->data, song->messages[value]->length);
 	    break;
 	  case COMMAND_HOLD:
 	    hold = value;
@@ -482,6 +482,10 @@ static void player_thread(struct player *player)
 	else
 	  player->trackstatus[i * TRACK_STATUS_NUMVALUES + TRACK_STATUS_HOLD] = hold;
       }
+      
+      /* First tick, no note but instrument defined? */
+      if (player->tick == 0 && note == 0 && instrument > 0 && player->trackstatus[i * TRACK_STATUS_NUMVALUES + TRACK_STATUS_HOLD] >= 0)
+        player->trackstatus[i * TRACK_STATUS_NUMVALUES + TRACK_STATUS_HOLD] += song->instruments[instrument - 1]->hold;
     }
 
     /* Decrement hold times of notes and stop notes that should be stopped */
@@ -610,10 +614,10 @@ struct player *player_open(struct song *song, struct editor *editor)
   /* Initialize notes playing array */
   player_trackstatus_create(player, 0);
 
-  /* Send SysEx messages to be autosent */
-  for (i = 0; i < player->song->numsysexes; i++) {
-    if (player->song->sysexes[i]->autosend)
-      midi_system_exclusive(player->midi, player->song->sysexes[i]->data, player->song->sysexes[i]->length);
+  /* Send messages to be autosent */
+  for (i = 0; i < player->song->nummessages; i++) {
+    if (player->song->messages[i]->autosend)
+      midi_write(player->midi, player->song->messages[i]->data, player->song->messages[i]->length);
   }
 
   /* Reset MIDI controller values */
